linux-next.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* linux-next: manual merge of the fbdev tree with the drm tree
@ 2022-10-04  2:27 Stephen Rothwell
  2022-10-04  7:29 ` Helge Deller
  0 siblings, 1 reply; 10+ messages in thread
From: Stephen Rothwell @ 2022-10-04  2:27 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Thomas Zimmermann, ruanjinjie

[-- Attachment #1: Type: text/plain, Size: 1254 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/tridentfb.c

between commit:

  145eed48de27 ("fbdev: Remove conflicting devices on PCI bus")

from the drm tree and commit:

  d738bf0123d6 ("fbdev: tridentfb: Fix missing pci_disable_device() in probe and remove")

from the fbdev tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging.  You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

-- 
Cheers,
Stephen Rothwell

diff --cc drivers/video/fbdev/tridentfb.c
index f9c3b1d38fc2,4d08f4489a0a..000000000000
--- a/drivers/video/fbdev/tridentfb.c
+++ b/drivers/video/fbdev/tridentfb.c
@@@ -1471,11 -1465,7 +1466,11 @@@ static int trident_pci_probe(struct pci
  	int chip_id;
  	bool found = false;
  
 +	err = aperture_remove_conflicting_pci_devices(dev, "tridentfb");
 +	if (err)
 +		return err;
 +
- 	err = pci_enable_device(dev);
+ 	err = pcim_enable_device(dev);
  	if (err)
  		return err;
  

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: linux-next: manual merge of the fbdev tree with the drm tree
  2022-10-04  2:27 linux-next: manual merge of the fbdev tree with the drm tree Stephen Rothwell
@ 2022-10-04  7:29 ` Helge Deller
  0 siblings, 0 replies; 10+ messages in thread
From: Helge Deller @ 2022-10-04  7:29 UTC (permalink / raw)
  To: Stephen Rothwell, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Thomas Zimmermann, ruanjinjie

On 10/4/22 04:27, Stephen Rothwell wrote:
> Hi all,
>
> Today's linux-next merge of the fbdev tree got a conflict in:
>
>    drivers/video/fbdev/tridentfb.c
>
> between commit:
>
>    145eed48de27 ("fbdev: Remove conflicting devices on PCI bus")
>
> from the drm tree and commit:
>
>    d738bf0123d6 ("fbdev: tridentfb: Fix missing pci_disable_device() in probe and remove")
>
> from the fbdev tree.

Thanks for the notice!
I'll fix it up in the fbdev tree, either by dropping that offending patch or fix the conflict.

Helge


^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2023-12-13  0:58 Stephen Rothwell
  0 siblings, 0 replies; 10+ messages in thread
From: Stephen Rothwell @ 2023-12-13  0:58 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Matthew Wilcox (Oracle),
	Thomas Zimmermann

[-- Attachment #1: Type: text/plain, Size: 770 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/vermilion/vermilion.c

between commit:

  76f92201b821 ("fbdev: Push pgprot_decrypted() into mmap implementations")

from the drm tree and commit:

  d8a47ee16884 ("fbdev: Remove support for Carillo Ranch driver")

from the fbdev tree.

I fixed it up (I just removed the file) and can carry the fix as
necessary. This is now fixed as far as linux-next is concerned, but any
non trivial conflicts should be mentioned to your upstream maintainer
when your tree is submitted for merging.  You may also want to consider
cooperating with the maintainer of the conflicting tree to minimise any
particularly complex conflicts.

-- 
Cheers,
Stephen Rothwell

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2023-12-13  0:56 Stephen Rothwell
  0 siblings, 0 replies; 10+ messages in thread
From: Stephen Rothwell @ 2023-12-13  0:56 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Linus Walleij, Linux Kernel Mailing List,
	Linux Next Mailing List, Thomas Zimmermann

[-- Attachment #1: Type: text/plain, Size: 758 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/amba-clcd.c

between commit:

  76f92201b821 ("fbdev: Push pgprot_decrypted() into mmap implementations")

from the drm tree and commit:

  13366c25125e ("fbdev: amba-clcd: Delete the old CLCD driver")

from the fbdev tree.

I fixed it up (I just deleted the file) and can carry the fix as
necessary. This is now fixed as far as linux-next is concerned, but any
non trivial conflicts should be mentioned to your upstream maintainer
when your tree is submitted for merging.  You may also want to consider
cooperating with the maintainer of the conflicting tree to minimise any
particularly complex conflicts.

-- 
Cheers,
Stephen Rothwell

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2023-08-01  0:43 Stephen Rothwell
  0 siblings, 0 replies; 10+ messages in thread
From: Stephen Rothwell @ 2023-08-01  0:43 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Fabio Estevam, Linux Kernel Mailing List,
	Linux Next Mailing List, Thomas Zimmermann

[-- Attachment #1: Type: text/plain, Size: 754 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/mx3fb.c

between commit:

  8a4675ebbd30 ("fbdev: Remove FBINFO_FLAG_DEFAULT from framebuffer_alloc()'ed structs")

from the drm tree and commit:

  87ac8777d424 ("fbdev: mx3fb: Remove the driver")

from the fbdev tree.

I fixed it up (I just removed the file) and can carry the fix as
necessary. This is now fixed as far as linux-next is concerned, but any
non trivial conflicts should be mentioned to your upstream maintainer
when your tree is submitted for merging.  You may also want to consider
cooperating with the maintainer of the conflicting tree to minimise any
particularly complex conflicts.

-- 
Cheers,
Stephen Rothwell

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2023-06-20  1:38 Stephen Rothwell
  0 siblings, 0 replies; 10+ messages in thread
From: Stephen Rothwell @ 2023-06-20  1:38 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Thomas Zimmermann

[-- Attachment #1: Type: text/plain, Size: 1666 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/hitfb.c

between commit:

  bb47f218fd01 ("fbdev/hitfb: Cast I/O offset to address")

from the drm tree and commit:

  dadeeffbe525 ("fbdev: hitfb: Use NULL for pointers")

from the fbdev tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging.  You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

-- 
Cheers,
Stephen Rothwell

diff --cc drivers/video/fbdev/hitfb.c
index 7737923b7a0a,5f544a177033..000000000000
--- a/drivers/video/fbdev/hitfb.c
+++ b/drivers/video/fbdev/hitfb.c
@@@ -444,10 -428,10 +444,10 @@@ static int hitfb_suspend(struct device 
  {
  	u16 v;
  
- 	hitfb_blank(1,0);
+ 	hitfb_blank(1, NULL);
 -	v = fb_readw(HD64461_STBCR);
 +	v = hitfb_readw(HD64461_STBCR);
  	v |= HD64461_STBCR_SLCKE_IST;
 -	fb_writew(v, HD64461_STBCR);
 +	hitfb_writew(v, HD64461_STBCR);
  
  	return 0;
  }
@@@ -456,13 -440,13 +456,13 @@@ static int hitfb_resume(struct device *
  {
  	u16 v;
  
 -	v = fb_readw(HD64461_STBCR);
 +	v = hitfb_readw(HD64461_STBCR);
  	v &= ~HD64461_STBCR_SLCKE_OST;
  	msleep(100);
 -	v = fb_readw(HD64461_STBCR);
 +	v = hitfb_readw(HD64461_STBCR);
  	v &= ~HD64461_STBCR_SLCKE_IST;
 -	fb_writew(v, HD64461_STBCR);
 +	hitfb_writew(v, HD64461_STBCR);
- 	hitfb_blank(0,0);
+ 	hitfb_blank(0, NULL);
  
  	return 0;
  }

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: linux-next: manual merge of the fbdev tree with the drm tree
  2022-12-13  0:16 Stephen Rothwell
@ 2022-12-13 11:10 ` Helge Deller
  0 siblings, 0 replies; 10+ messages in thread
From: Helge Deller @ 2022-12-13 11:10 UTC (permalink / raw)
  To: Stephen Rothwell, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Randy Dunlap, Thomas Zimmermann

On 12/13/22 01:16, Stephen Rothwell wrote:
> Today's linux-next merge of the fbdev tree got a conflict in:
>    drivers/video/fbdev/Kconfig
> between commit:
>    c8a17756c425 ("drm/ofdrm: Add ofdrm for Open Firmware framebuffers")
> from the drm tree and commit:
>    225e095bbd3a ("fbdev: offb: make offb driver tristate")
> from the fbdev tree.

I've dropped that patch from the fbdev git tree to resolve the
conflict. It didn't applied cleanly anyway, so @Randy please
resend a new patch if required.

Thanks!
Helge



> I fixed it up (see below) and can carry the fix as necessary. This
> is now fixed as far as linux-next is concerned, but any non trivial
> conflicts should be mentioned to your upstream maintainer when your tree
> is submitted for merging.  You may also want to consider cooperating
> with the maintainer of the conflicting tree to minimise any particularly
> complex conflicts.
>


^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2022-12-13  0:16 Stephen Rothwell
  2022-12-13 11:10 ` Helge Deller
  0 siblings, 1 reply; 10+ messages in thread
From: Stephen Rothwell @ 2022-12-13  0:16 UTC (permalink / raw)
  To: Helge Deller, Dave Airlie
  Cc: DRI, Linux Kernel Mailing List, Linux Next Mailing List,
	Randy Dunlap, Thomas Zimmermann

[-- Attachment #1: Type: text/plain, Size: 1307 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in:

  drivers/video/fbdev/Kconfig

between commit:

  c8a17756c425 ("drm/ofdrm: Add ofdrm for Open Firmware framebuffers")

from the drm tree and commit:

  225e095bbd3a ("fbdev: offb: make offb driver tristate")

from the fbdev tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging.  You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

-- 
Cheers,
Stephen Rothwell

diff --cc drivers/video/fbdev/Kconfig
index 71019b167f8b,a529511f7f53..000000000000
--- a/drivers/video/fbdev/Kconfig
+++ b/drivers/video/fbdev/Kconfig
@@@ -456,9 -453,8 +456,9 @@@ config FB_ATAR
  	  chipset found in Ataris.
  
  config FB_OF
- 	bool "Open Firmware frame buffer device support"
- 	depends on (FB = y) && PPC && (!PPC_PSERIES || PCI)
+ 	tristate "Open Firmware frame buffer device support"
+ 	depends on FB && PPC && (!PPC_PSERIES || PCI)
 +	depends on !DRM_OFDRM
  	select APERTURE_HELPERS
  	select FB_CFB_FILLRECT
  	select FB_CFB_COPYAREA

[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: linux-next: manual merge of the fbdev tree with the drm tree
  2013-06-17  4:21 Stephen Rothwell
@ 2013-06-17  7:23 ` Tomi Valkeinen
  0 siblings, 0 replies; 10+ messages in thread
From: Tomi Valkeinen @ 2013-06-17  7:23 UTC (permalink / raw)
  To: Stephen Rothwell, Jean-Christophe PLAGNIOL-VILLARD, Dave Airlie
  Cc: Florian Tobias Schandinat, linux-fbdev, linux-next, linux-kernel,
	Steffen Trumtrar

[-- Attachment #1: Type: text/plain, Size: 748 bytes --]

Hi,

On 17/06/13 07:21, Stephen Rothwell wrote:
> Hi all,
> 
> Today's linux-next merge of the fbdev tree got a conflict in
> drivers/video/of_display_timing.c between commit f583662347c6 ("video:
> display_timing: make parameter const") from the drm tree and commits
> fcf7e6e5bd84 ("videomode: don't allocate mem in of_get_display_timing()")
> and ffa3fd21de8a ("videomode: implement public of_get_display_timing()")
> from the fbdev tree.
> 
> I fixed it up (see below) and can carry the fix as necessary (no action
> is required).

Thanks, looks correct to me.

I guess it'd be better to merge videomode and display_timing stuff via a
single tree from this on. Being in drivers/video/, I suggest the fbdev tree.

 Tomi



[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 901 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

* linux-next: manual merge of the fbdev tree with the drm tree
@ 2013-06-17  4:21 Stephen Rothwell
  2013-06-17  7:23 ` Tomi Valkeinen
  0 siblings, 1 reply; 10+ messages in thread
From: Stephen Rothwell @ 2013-06-17  4:21 UTC (permalink / raw)
  To: Jean-Christophe PLAGNIOL-VILLARD, Florian Tobias Schandinat,
	Tomi Valkeinen, linux-fbdev
  Cc: linux-next, linux-kernel, Steffen Trumtrar, Dave Airlie

[-- Attachment #1: Type: text/plain, Size: 1332 bytes --]

Hi all,

Today's linux-next merge of the fbdev tree got a conflict in
drivers/video/of_display_timing.c between commit f583662347c6 ("video:
display_timing: make parameter const") from the drm tree and commits
fcf7e6e5bd84 ("videomode: don't allocate mem in of_get_display_timing()")
and ffa3fd21de8a ("videomode: implement public of_get_display_timing()")
from the fbdev tree.

I fixed it up (see below) and can carry the fix as necessary (no action
is required).

-- 
Cheers,
Stephen Rothwell                    sfr@canb.auug.org.au

diff --cc drivers/video/of_display_timing.c
index 2894e03,9c0f17b..0000000
--- a/drivers/video/of_display_timing.c
+++ b/drivers/video/of_display_timing.c
@@@ -53,13 -53,12 +53,12 @@@ static int parse_timing_property(const 
  }
  
  /**
   * of_get_display_timing - parse display_timing entry from device_node
   * @np: device_node with the properties
   **/
- static struct display_timing *of_get_display_timing(const struct device_node
- 						    *np)
 -static int of_parse_display_timing(struct device_node *np,
++static int of_parse_display_timing(const struct device_node *np,
+ 		struct display_timing *dt)
  {
- 	struct display_timing *dt;
  	u32 val = 0;
  	int ret = 0;
  

[-- Attachment #2: Type: application/pgp-signature, Size: 836 bytes --]

^ permalink raw reply	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2023-12-13  0:58 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-10-04  2:27 linux-next: manual merge of the fbdev tree with the drm tree Stephen Rothwell
2022-10-04  7:29 ` Helge Deller
  -- strict thread matches above, loose matches on Subject: below --
@@@ -53,13 -53,12 +53,12 @@@ static int parse_timing_property(const 
  
  /**
-  * of_get_display_timing - parse display_timing entry from device_node
+  * of_parse_display_timing - parse display_timing entry from device_node
   * @np: device_node with the properties
   **/
2023-12-13  0:58 Stephen Rothwell
2023-12-13  0:56 Stephen Rothwell
2023-08-01  0:43 Stephen Rothwell
2023-06-20  1:38 Stephen Rothwell
2022-12-13  0:16 Stephen Rothwell
2022-12-13 11:10 ` Helge Deller
2013-06-17  4:21 Stephen Rothwell
2013-06-17  7:23 ` Tomi Valkeinen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).